@@ -10,6 +10,10 @@ OC.L10N.register(
     "Mail" : "E-pasts",
     "Mails" : "E-pasta sūtījumi",
     "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
+    "Connecting" : "Savienojuma izveide",
+    "Save" : "Saglabāt",
+    "Connect" : "Savienoties",
+    "Password required" : "Nepieciešama parole",
     "Auto" : "Automātiski",
     "Name" : "Nosaukums",
     "Mail address" : "E-pasta adrese",
@@ -30,10 +34,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP Port",
     "SMTP User" : "SMTP lietotājs",
     "SMTP Password" : "SMTP parole",
-    "Connecting" : "Savienojuma izveide",
-    "Save" : "Saglabāt",
-    "Connect" : "Savienoties",
-    "Password required" : "Nepieciešama parole",
     "Account settings" : "Konta iestatījumi",
     "Aliases" : "Aizstājvārdi",
     "Signature" : "Paraksts",
@@ -55,9 +55,9 @@ OC.L10N.register(
     "Write message …" : "Rakstiet ziņu...",
     "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
     "Enter a date" : "Ievadiet datumu",
+    "Choose" : "Izvēlēties",
     "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
     "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
-    "Choose" : "Izvēlēties",
     "Confirm" : "Apstiprināt",
     "Favorite" : "Izlasē",
     "Read" : "Lasīt",
@@ -72,7 +72,7 @@ OC.L10N.register(
     "Comment" : "Piebilde",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
-    "More options" : "Vairāk opciju",
+    "More options" : "Vairāk iespēju",
     "Remove" : "Noņemt",
     "email" : "e-pasts",
     "Other" : "Cits",
@@ -80,38 +80,39 @@ OC.L10N.register(
     "Forward" : "Turpināt",
     "Translate" : "Tulkot",
     "View source" : "Skatīt avotu",
+    "Unnamed" : "Nenosaukts",
     "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
     "Import into calendar" : "Importēt kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
-    "Unnamed" : "Nenosaukts",
     "Save all to Files" : "Saglabāt visu uz Datnes",
     "The images have been blocked to protect your privacy." : "Attēli tika aizturēti, lai aizsargātu Tavu privātumu.",
     "Show images" : "Parādīt attēlus",
     "Show images temporarily" : "Īslaicīgi parādīt attēlus",
     "Move" : "Pārvietot",
+    "Loading …" : "Ielādē…",
+    "Remove account" : "Noņemt kontu",
     "Quota" : "Kvota",
     "Saving" : "Saglabā",
-    "Remove account" : "Noņemt kontu",
-    "Loading …" : "Ielādē…",
     "Rename" : "Pārsaukt",
     "Subscribed" : "Abonēts",
     "New message" : "Jauna ziņa",
+    "Reply" : "Atbildēt",
     "Retry" : "Mēģināt vēlreiz",
     "Sending …" : "Sūta …",
-    "Reply" : "Atbildēt",
     "Message" : "Ziņojums",
     "Copy to clipboard" : "Kopēt starpliktuvē",
     "Add" : "Pievienot",
     "Show more" : "Parādīt vairāk",
+    "Clear" : "Notīrīt",
     "Search in mailbox" : "Meklēt pastkastē",
     "Close" : "Aizvērt",
     "Date" : "Datums",
     "Tags" : "Birkas",
     "Select tags" : "Atlasīt birkas",
-    "Clear" : "Notīrīt",
     "Custom" : "Pielāgots",
     "Delete tag" : "Dzēst atzīmi",
+    "Tag name is a hidden system tag" : "Birkas nosaukums ir slēpta sistēmas birka",
     "Tag already exists" : "Birka jau pastāv",
     "Not found" : "Nav atrasts",
     "Untitled event" : "Nenosaukts notikums",
@@ -145,7 +146,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s",
-    "Unselect" : "Noņemt atlasi"
+    "Continue to %s" : "Turpināt %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
